@@ -3,7 +3,7 @@
 import os
 import click
 
-from .common import render_source, generate
+from .common import load_and_check_params, check_overwrite, render_source
 
 
 BOARD_PARAMS = {
@@ -16,7 +16,7 @@ BOARD_PARAMS = {
     "cpu_model": {"args": ["CPU model name"], "kwargs": {}},
 }
 
-BOARD_PARAMS_LIST = ["features"]
+BOARD_PARAMS_LIST = ["features_provided"]
 
 BOARD_FILES = {
     filename: None
@@ -36,26 +36,21 @@ BOARD_INCLUDE_FILES = {filename: None for filename in ["board.h", "periph_conf.h
 def generate_board(interactive, config, riotbase):
     """Generate the code for a board support."""
     group = "board"
-    params, output_dir = generate(
-        group,
-        BOARD_PARAMS,
-        BOARD_PARAMS_LIST,
-        BOARD_FILES,
-        interactive,
-        config,
-        riotbase,
-        in_riot_dir="boards",
+    params = load_and_check_params(
+        group, BOARD_PARAMS, BOARD_PARAMS_LIST, interactive, config, riotbase, "boards",
     )
 
+    output_dir = os.path.join(riotbase, "boards", params[group]["name"])
+    check_overwrite(output_dir)
+
+    render_source(params, group, BOARD_FILES, output_dir)
     render_source(
         params, group, BOARD_INCLUDE_FILES, os.path.join(output_dir, "include"),
     )
 
     click.echo(
         click.style(
-            "Support for {group} '{board}' generated in {output_dir} with success!".format(
-                group=group, board=params[group]["name"], output_dir=output_dir
-            ),
+            f"Support for {group} '{params[group]['name']}' generated in {output_dir} with success!",
             bold=True,
         )
     )
