@@ -3,7 +3,7 @@
 import os
 import click
 
-from .common import render_source, generate
+from .common import load_and_check_params, check_overwrite, render_source
 
 
 MODULE_PARAMS = {
@@ -23,26 +23,20 @@ MODULE_INCLUDE_FILES = {"module.h": "{name}.h"}
 def generate_module(interactive, config, riotbase):
     """Generate the code of a module."""
     group = "module"
-    params, output_dir = generate(
-        group,
-        MODULE_PARAMS,
-        [],
-        MODULE_FILES,
-        interactive,
-        config,
-        riotbase,
-        in_riot_dir="sys",
+    params = load_and_check_params(
+        group, MODULE_PARAMS, [], interactive, config, riotbase, "sys"
     )
 
-    render_source(
-        params, group, MODULE_INCLUDE_FILES, os.path.join(riotbase, "sys", "include"),
-    )
+    sys_dir = os.path.join(riotbase, "sys")
+    output_dir = os.path.join(sys_dir, params[group]["name"])
+    output_include_dir = os.path.join(sys_dir, "include")
+    check_overwrite(output_dir)
+    render_source(params, group, MODULE_FILES, output_dir)
+    render_source(params, group, MODULE_INCLUDE_FILES, output_include_dir)
 
     click.echo(
         click.style(
-            "Module '{board}' generated in {output_dir} with success!".format(
-                board=params[group]["name"], output_dir=output_dir
-            ),
+            f"Module '{params[group]['name']}' generated in {output_dir} with success!",
             bold=True,
         )
     )
